.feedback_window 
{
  position:fixed;
  bottom:5px;
  right:5px;
  width:230px;
  text-align:right;
  color:#000;
  z-index: 999;
  font-size: 12px;
  box-sizing: border-box;
  font-family:Verdana,sans-serif;
}

.feedback_window .feedback_extra
{
  box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3); 
  background-color: #ffffff;
  border-radius: 6px;
  text-align:left;
}

.feedback_window .feedback_top
{
  padding-left:6px;
  padding-right:6px;
  padding-top:6px;
  text-align:center;
  color: #555;
}

.feedback_extra textarea
{
  box-sizing: border-box;
  margin-top:5px;
  width:100%;
  background-color:#f5f5f5;
  padding:2px;
  font-size: 12px;
  color: #000;
  font-weight: normal;
  font-family:Verdana,sans-serif;
  border:1px solid #ddd;
  font-style:italic;
}

.feedback_extra textarea:hover
{
  border:1px solid #bbb;
}

.feedback_actions
{
  box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3); 
  border-top: 1px solid #ddd;
  background-color:#f5f5f5;
  padding:5px;
  margin-top:5px;
  text-align:center;
  border-radius: 0 0 6px 6px;
}

.feedback_actions button {
  width:106px;
  margin:2px;
}

.feedback_actions .feedback_cancel {
  color:#777;
}

.feedback_hover {
  outline: 5px solid #fffc73 !important;
  z-index:500;
}

.feedback_selected {
  outline: 5px solid red !important;
  z-index:500;
}

.feedback-btn {
  display: inline-block;
  *display: inline;
  padding: 4px 12px;
  margin-bottom: 0;
  *margin-left: .3em;
  font-size: 14px;
  line-height: 20px;
  color: #333333;
  text-align: center;
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);
  vertical-align: middle;
  cursor: pointer;
  background-color: #f5f5f5;
  *background-color: #e6e6e6;
  background-image: -moz-linear-gradient(top, #ffffff, #e6e6e6);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ffffff), to(#e6e6e6));
  background-image: -webkit-linear-gradient(top, #ffffff, #e6e6e6);
  background-image: -o-linear-gradient(top, #ffffff, #e6e6e6);
  background-image: linear-gradient(to bottom, #ffffff, #e6e6e6);
  background-repeat: repeat-x;
  border: 1px solid #cccccc;
  *border: 0;
  border-color: #e6e6e6 #e6e6e6 #bfbfbf;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  border-bottom-color: #b3b3b3;
  border-radius: 4px;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffffff', endColorstr='#ffe6e6e6', GradientType=0);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled=false);
  *zoom: 1;
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
}
.feedback-btn:hover,
.feedback-btn:active,
.feedback-btn.active,
.feedback-btn.disabled,
.feedback-btn[disabled] {
  background-color: #e6e6e6;
}
.feedback-btn:active, .feedback-btn.active {
  background-color: #cccccc;
}

.feedback-btn:first-child {
  *margin-left: 0;
}
.feedback-btn:hover {
  color: #333333;
  text-decoration: none;
  background-color: #e6e6e6;
  background-position: 0 -15px;
  transition: background-position 0.1s linear;
}
.feedback-btn:focus {
  outline: thin dotted #333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
.feedback-btn.active, .feedback-btn:active {
  background-image: none;
  box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.15), 0 1px 2px rgba(0, 0, 0, 0.05);
  background-color: #e6e6e6;
  outline: 0;
}
.feedback-btn.disabled, .feedback-btn[disabled] {
  cursor: default;
  background-image: none;
  background-color: #e6e6e6;
  opacity: 0.65;
  filter: alpha(opacity=65);
  box-shadow: none;
}

button.feedback-btn, input[type="submit"].feedback-btn {
  *padding-top: 2px;
  *padding-bottom: 2px;
}

button.feedback-btn::-moz-focus-inner, input[type="submit"].feedback-btn::-moz-focus-inner {
  padding: 0;
  border: 0;
}
